;This was developed to be used with an ATV system installed on a BOE-BOT to stimulate
;the sending of the operators call sign at intervals of approximately 8.5 minutes.  The
;Morse code ID is generated within the BStamp on the BOE-BOT.  When the chip is first powered
;the delay loops begin to time for 5.5 minutes.  At the end of the delay time, Pin 0 goes
;high to signal the BStamp that it is time to send the Morse ID through the ATV audio channel.
;Once the BStamp completes the Morse ID, the BStamp will send a high pulse to Pin 0 of the 12F675,
;which will be sensed that the ID has started and the timer will reset.  If when Pin 0 is sensed and 
;a low is detected, then the ID pulse was not detected by the Stamp and the 12F675 sends another
;pulse.  My call sign is WA8SME, I can be reached at 530-495-9150 or e-mail mspencer@arrl.org.
;Happy decoding de Mark Spencer.


	list      p=12F675       ; list directive to define processor
	#include <p12f675.inc>    ; processor specific variable definitions

	__CONFIG  _CP_OFF & _WDT_OFF & _BODEN_ON & _PWRTE_ON & _INTRC_OSC_NOCLKOUT & _MCLRE_OFF & _CPD_OFF

; '__CONFIG' directive is used to embed configuration word within .asm file.
; The labels following the directive are located in the respective .inc file.
; See data sheet for additional information on configuration word settings.

;******************************************************************************
;Defines
;******************************************************************************

#define Bank0			0x00
#define	Bank1			0x80
#define D0_1Tris		b'00000000'		;GPIO pins all outputs
#define	ID_out			GPIO,0			;pin tied to BStamp pin used to send ID


;******************************************************************************
;General Purpose Registers (GPR's) 
;******************************************************************************

	cblock	0x20
	countH								;for wait time counter
	tempa								;for delays
	count								;for delays
	endc

;******************************************************************************
;Reset Vector 
;******************************************************************************
	ORG     0x000         	; processor reset vector
	nop						; required by in circuit debugger  
	goto    Init            ; go to beginning of program

;******************************************************************************
;Interrupt Vector     
;******************************************************************************
	ORG	0x004
	;goto interupt_service_routine		;goto interupt_service on falling edge on
										;GP2
	RETURN			
;******************************************************************************
;Initialization
;******************************************************************************
Init
	
	;call    0x3FF      ; retrieve factory calibration value
						; comment instruction if using simulator, ICD2, or ICE2000
	BANKSEL	Bank1		; BANK1
	movwf   OSCCAL      ; update register with factory cal value 
	movlw	D0_1Tris	; set direction all output
	movwf	TRISIO		; 
	clrf	ANSEL		; configure A/D I/O as digital	
	bsf		OPTION_REG,7;disable weak pull ups
	BANKSEL	Bank0		; change back to PORT memory bank
	movlw	0x007		; disconnect comparitor
	movwf	CMCON		;
	clrf	INTCON		;no interupts
	clrf	GPIO		;clear output port

;******************************************************************************
;Main 
;******************************************************************************

Main
	movlw	.60
	movwf	countH
	
loop1
	call	wait1sec	
	decfsz	countH,f	
	goto	loop1
loop2
	call	wait1sec	
	decfsz	countH,f	
	goto	loop2

	goto	send_ID

	goto	Main

;******************************************************************************
;Subroutines & Functions
;******************************************************************************
send_ID
	bsf		ID_out		;a high on this pin will signal BStamp to send Morse ID
	call	wait100mS
	call	wait50mS
	bcf		ID_out
	BANKSEL	Bank1
	bsf		TRISIO,0	;set GPIO pin 0 to input-tristate
	BANKSEL	Bank0
	btfss	GPIO,0		;skip if no Morse being sent
	goto	continue
	BANKSEL	Bank1
	bcf		TRISIO,0	;set GPIO pin 0 to output
	BANKSEL	Bank0
	goto	send_ID		;return to continue to trigger Morse
continue
	BANKSEL	Bank1
	bcf		TRISIO,0	;set GPIO pin 0 to output
	BANKSEL	Bank0
	goto 	Main	

interupt_service_routine

;	bcf		INTCON,4	;disable further interupts
;	bcf		ID_out		;clear send ID flag and allows next Morse ID stimulus
;	bcf		INTCON,1	;clear interupt flag
;	bsf		INTCON,4	;enble interups
	retfie				;end of interupt service routine


;delay routines here
;******************************************************************************
;Delay Routines
;******************************************************************************
;more delay options than needed, this is standard delay code I use in other programs
wait1sec
		call	wait300mS
		call	wait300mS
		call	wait300mS
		goto	wait100mS
wait300mS
        call    delay50mS
wait250mS
        call    delay50mS
        call    delay50mS
        call    delay50mS
wait100mS
        call    delay50mS
wait50mS
        call    delay50mS
		return
;delay1ms, is a very accurate 1mS delay for a 4Mhz clock.
delay1mS
        movlw   .197
        movwf   count
        nop
        goto    $+1
        goto    $+1
dly1mS        
        goto    $+1
        decfsz  count, F
        goto    dly1mS
        return
;delay5mS uses delay1mS to get a very accurate 5 mS delay
delay5mS
        call    delay1mS
        call    delay1mS
        call    delay1mS
        call    delay1mS
        call    delay1mS
        movlw   .4
        movwf   count
tweek5mS
        decfsz  count, F
        goto    tweek5mS
        return
;delay50mS uses delay1mS to get a very accurate 50mS delay
delay50mS
        movlw   .50
        movwf   tempa
dly50mS
        call    delay1mS
        decfsz  tempa, F
        goto    dly50mS
        movlw   .14
        movwf   count
tweek50mS
        decfsz  count, F
        goto    tweek50mS
        return
;delay200mS uses delay1mS to get a very accurate 200mS delay.
delay200mS
        movlw   .200
        movwf   tempa
dly200mS
        call    delay1mS
        decfsz  tempa, F
        goto    dly200mS
        movlw   .64
        movwf   count
tweek200mS
        decfsz  count, F
        goto    tweek200mS
        return
;end delay rountines



	END			; directive 'end of program'


